@@ -1,9 +1,9 @@
 import getpass
 
 
-class SimpleVars(dict):
+class SettingVars(dict):
     def __init__(self, input_dict):
-        super(SimpleVars, self).__init__()
+        super(SettingVars, self).__init__()
         self.log_name = input_dict.get('log_name', 'python app(%s)' % getpass.getuser())
         self.log_file = input_dict.get('log_file', '/tmp/simplesettings.log')
         self.verbosity = input_dict.get('log_verbosity', 4)
